/*
 * Copyright 2016 ISP RAS (http://www.ispras.ru)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase.generator;

import java.util.Set;

import ru.ispras.fortress.util.InvariantChecks;
import ru.ispras.testbase.TestBaseContext;
import ru.ispras.testbase.TestBaseQuery;
import ru.ispras.testbase.TestDataProvider;

public abstract class DataGeneratorBase implements DataGenerator {
  private final String name;
  private final Set<String> instructions;

  public DataGeneratorBase(final String name, final Set<String> instructions) {
    InvariantChecks.checkNotNull(name);

    this.name = name;
    this.instructions = instructions;
  }

  public DataGeneratorBase(final String name) {
    this(name, null);
  }

  public final String getName() {
    return name;
  }

  @Override
  public boolean isSuitable(final TestBaseQuery query) {
    InvariantChecks.checkNotNull(query);

    if (!name.equals(query.getContext().get(TestBaseContext.TESTCASE))) {
      return false;
    }

    if (null != instructions &&
       !instructions.contains(query.getContext().get(TestBaseContext.INSTRUCTION))) {
      return false;
    }

    return true;
  }

  @Override
  public final TestDataProvider generate(final TestBaseQuery query) {
    InvariantChecks.checkNotNull(query);
    final DataGeneratorQuery internalQuery = new DataGeneratorQuery(query);

    generate(internalQuery);
    return TestDataProvider.singleton(internalQuery.buildTestData());
  }

  protected abstract void generate(final DataGeneratorQuery query);
}
