/*
 * Copyright 2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase.knowledge.floating;

import java.util.HashMap;
import java.util.Map;

/**
 * {@link FpException} contains the IEEE 754 floating-point exceptions.
 * 
 * @author <a href="mailto:kamkin@ispras.ru">Alexander Kamkin</a>
 */
public enum FpException {
  NORMAL,
  OVERFLOW,
  UNDERFLOW,
  INEXACT;

  private static final Map<String, FpException> names;

  static {
    names = new HashMap<String, FpException>();
    for (final FpException exception : values()) {
      names.put(exception.name(), exception);
    }
  }

  public static FpException get(final String name) {
    return names.get(name.toUpperCase());
  }
}
